@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::MSCHOUT;
 BEGIN {
-  $Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.21';
+  $Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.22';
 }
 
 # ABSTRACT: Use L<Dist::Zilla> like MSCHOUT does
@@ -10,6 +10,13 @@ use Moose::Autobox;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+has is_task => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { $_[0]->payload->{task} }
+);
+
 sub configure {
     my $self = shift;
 
@@ -25,6 +32,8 @@ sub configure {
         push @remove, 'UploadToCPAN', 'ConfirmRelease';
     }
 
+    $self->add_plugins('CheckPrereqsIndexed');
+
     $self->add_bundle(Filter => {
         bundle => '@Classic',
         remove => \@remove
@@ -45,13 +54,27 @@ sub configure {
             ArchiveRelease
         ),
         # update release in Changes file
-        [ NextRelease => { format => '%-2v  %{yyyy-MM-dd}d' } ],
-        [ PodWeaver => { config_plugin => '@MSCHOUT' } ],
+        [ NextRelease => { format => '%-2v  %{yyyy-MM-dd}d' } ]
+    );
+
+    if ($self->is_task) {
+        $self->add_plugins(
+            'TaskWeaver',
+            [ AutoVersion => { time_zone => 'America/Chicago' } ]
+        );
+    }
+    else {
+        $self->add_plugins(
+            [ PodWeaver => { config_plugin => '@MSCHOUT' } ],
+            [ 'BumpVersionFromGit' => { first_version => '0.01' } ]
+        );
+    }
+
+    $self->add_plugins(
         qw(
             Git::Check
             Git::Commit
         ),
-        [ 'BumpVersionFromGit' => { first_version => '0.01' } ],
         [ 'Git::CommitBuild' => { release_branch => $release_branch } ],
         [ 'Git::Tag' => { branch => $release_branch } ],
         qw(
@@ -74,7 +97,7 @@ Dist::Zilla::PluginBundle::MSCHOUT - Use L<Dist::Zilla> like MSCHOUT does
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 DESCRIPTION
 
@@ -117,14 +140,25 @@ The following configuration settings are available:
 
 =over 4
 
-=item * no_upload
+=item *
+
+no_upload
 
 Disables C<UploadToCPAN> and C<ConfirmRelease>.  Adds C<FakeRelease>.
 
-=item * release_branch
+=item *
+
+release_branch
 
 Sets the release branch name.  Default is C<build/releases>.
 
+=item *
+
+task
+
+Replaces C<Pod::Weaver> with C<Task::Weaver> and uses C<AutoVersion> instead of
+C<BumpVersionFromGit>
+
 =back
 
 =for Pod::Coverage configure
